function [Hid_C3H8] = AL_Hid_C3H8 (T)
% AL_Hid_C3H8 - Enthalpy calculation using Aly-Lee Equation
% Aly, F.A. and Lee, L.L., Self-Consistent Equations for Calculating the Ideal Gas
% Heat Capacity, Enthalpy and Entropy, Fluid Phase Equilibria, 6 (1981) pp 169-179.
% Just for C3H8
% call: [T] = [K]
% return: Hid_C3H8 = [J/mol]


% ----------------------------------------------------------------------------- Parameters
% From Aly&Lee_1981 Table 1, p 174

% --------------------------- C3H8 (298.15-1500 K)
A_C3H8 =    -58099.3 * 4.184  ;                                     % [J/mol]
B_C3H8 =     13.7962 * 4.184  ;                                     % [J/mol/K]
C_C3H8 =     45.4301 * 4.184  ;                                     % [J/mol/K]
D_C3H8 =  1802.34             ;                                     % [K]
E_C3H8 =     30.1245 * 4.184  ;                                     % [J/mol/K]
F_C3H8 =   815.820            ;                                     % [K]
G_C3H8 =    -25.4424 * 4.184  ;                                     % [J/mol/K]

A = A_C3H8; B = B_C3H8; C = C_C3H8; D = D_C3H8; E = E_C3H8; F = F_C3H8; G = G_C3H8;

% T = 100  ;                                                         % [K]

Hid_C3H8= B*T + C*T*(D/T)*coth(D/T) - E*T*(F/T)*tanh(F/T) + A ;  % [J/mol]
                       
return  ;