function [Hid_CH4] = AL_Hid_CH4 (T)
% AL_Hid_CH4 - Enthalpy calculation using Aly-Lee Equation
% Aly, F.A. and Lee, L.L., Self-Consistent Equations for Calculating the Ideal Gas
% Heat Capacity, Enthalpy and Entropy, Fluid Phase Equilibria, 6 (1981) pp 169-179.
% Just for CH4
% call: [T] = [K]
% return: Hid_CH4 = [J/mol]


% ----------------------------------------------------------------------------- Parameters
% From Aly&Lee_1981 Table 1, p 174

% --------------------------- CH4 (298.15-1500 K)
A_CH4 =    -30787.5 * 4.184  ;                                     % [J/mol]
B_CH4 =     8.00318 * 4.184  ;                                     % [J/mol/K]
C_CH4 =     19.2633 * 4.184  ;                                     % [J/mol/K]
D_CH4 =  2148.79             ;                                     % [K]
E_CH4 =     10.4423 * 4.184  ;                                     % [J/mol/K]
F_CH4 =  1017.07             ;                                     % [K]
G_CH4 =    -7.28270 * 4.184  ;                                     % [J/mol/K]

A = A_CH4; B = B_CH4; C = C_CH4; D = D_CH4; E = E_CH4; F = F_CH4; G = G_CH4;

% T = 100  ;                                                         % [K]

Hid_CH4= B*T + C*T*(D/T)*coth(D/T) - E*T*(F/T)*tanh(F/T) + A ;  % [J/mol]
                       
return  ;