function [Hid_N2] = AL_Hid_N2 (T)
% AL_Sid_N2 - Enthalpy calculation using Aly-Lee Equation
% Aly, F.A. and Lee, L.L., Self-Consistent Equations for Calculating the Ideal Gas
% Heat Capacity, Enthalpy and Entropy, Fluid Phase Equilibria, 6 (1981) pp 169-179.
% Just for N2
% call: [T] = [K]
% return: Hid_N2 = [J/mol]


% ----------------------------------------------------------------------------- Parameters
% From Aly&Lee_1981 Table 1, p 174

% --------------------------- N2 (273.15-1500 K)
A_N2  =    -119.390  *  4.184 ;                                     % [J/mol]
B_N2  =     6.95808  *  4.184 ;                                     % [J/mol/K]
C_N2  =     2.03952  *  4.184 ;                                     % [J/mol/K]
D_N2  =  1681.60              ;                                     % [K]
E_N2  =     0.506863 *  4.184 ;                                     % [J/mol/K]
F_N2  =  6535.66              ;                                     % [K]
G_N2  =     5.05495  *  4.184 ;                                     % [J/mol/K]

A = A_N2 ; B = B_N2 ; C = C_N2 ; D = D_N2 ; E = E_N2 ; F = F_N2 ; G = G_N2 ;

% T = 100  ;                                                        % [K]

Hid_N2 = B*T + C*T*(D/T)*coth(D/T) - E*T*(F/T)*tanh(F/T) + A ;      % [J/mol] 
                       
return  ;