function [Hid_O2] = AL_Hid_O2 (T)
% AL_Hid_O2 - Enthalpy calculation using Aly-Lee Equation
% Aly, F.A. and Lee, L.L., Self-Consistent Equations for Calculating the Ideal Gas
% Heat Capacity, Enthalpy and Entropy, Fluid Phase Equilibria, 6 (1981) pp 169-179.
% Just for O2
% call: [T] = [K]
% return: Hid_O2 = [J/mol]


% ----------------------------------------------------------------------------- Parameters
% From Aly&Lee_1981 Table 1, p 174

% --------------------------- O2 (273.15-1500 K)
A_O2  =    -3497.45 * 4.184  ;                                     % [J/mol]
B_O2  =     6.96302 * 4.184  ;                                     % [J/mol/K]
C_O2  =     2.40013 * 4.184  ;                                     % [J/mol/K]
D_O2  =  2522.05             ;                                     % [K]
E_O2  =     2.21752 * 4.184  ;                                     % [J/mol/K]
F_O2  =  1154.15             ;                                     % [K]
G_O2  =     9.19749 * 4.184  ;                                     % [J/mol/K]

A = A_O2 ; B = B_O2 ; C = C_O2 ; D = D_O2 ; E = E_O2 ; F = F_O2 ; G = G_O2 ;

% T = 100  ;                                                         % [K]

Hid_O2 = B*T + C*T*(D/T)*coth(D/T) - E*T*(F/T)*tanh(F/T) + A ;  % [J/mol]
                       
return  ;