function [Sid_CO2] = AL_Sid_CO2 (T)
% AL_Sid_CO2 - Entropy calculation using Aly-Lee Equation
% Aly, F.A. and Lee, L.L., Self-Consistent Equations for Calculating the Ideal Gas
% Heat Capacity, Enthalpy and Entropy, Fluid Phase Equilibria, 6 (1981) pp 169-179.
% Just for CO2
% call: [T] = [K]
% return: Sid_CO2 = [J/mol/K]


% ----------------------------------------------------------------------------- Parameters
% From Aly&Lee_1981 Table 1, p 174

% --------------------------- CO2 (273.15-1500 K)
A_CO2  = -7460.81     *  4.184 ;                                     % [J/mol]
B_CO2  =     7.54056  *  4.184 ;                                     % [J/mol/K]
C_CO2  =     7.51625  *  4.184 ;                                     % [J/mol/K]
D_CO2  =  1442.70              ;                                     % [K]
E_CO2  =     5.38023  *  4.184 ;                                     % [J/mol/K]
F_CO2  =   647.502             ;                                     % [K]
G_CO2  =     6.25230  *  4.184 ;                                     % [J/mol/K]

A = A_CO2 ; B = B_CO2 ; C = C_CO2 ; D = D_CO2 ; E = E_CO2 ; F = F_CO2 ; G = G_CO2 ;

% T = 100  ;                                                         % [K]

Sid_CO2 = B*log( T ) + C*( ( D/T)*coth( D/T ) - log( sinh( D/T ) ) ) - ...
                           E*( ( F/T)*tanh( F/T ) - log( cosh( F/T ) ) ) + G ;  % [J/mol/K]
                       
return  ;

% Poner Sid_CO2 (o cualquier otro nombre) = AL_Sid_CO2 (T) con el valor de T correspondiente; en la otra
% ventana