function [Sid_H2O] = AL_Sid_H2O (T)
% AL_Sid_H2O - Entropy calculation using Aly-Lee Equation
% Aly, F.A. and Lee, L.L., Self-Consistent Equations for Calculating the Ideal Gas
% Heat Capacity, Enthalpy and Entropy, Fluid Phase Equilibria, 6 (1981) pp 169-179.
% Just for H2O
% call: [T] = [K]
% return: Sid_H2O = [J/mol/K]


% ----------------------------------------------------------------------------- Parameters
% From Aly&Lee_1981 Table 1, p 174

% --------------------------- H2O (273.15-1500 K)
A_H2O  = -13773.1     *  4.184 ;                                     % [J/mol]
B_H2O  =     7.97183  *  4.184 ;                                     % [J/mol/K]
C_H2O  =     6.27078  *  4.184 ;                                     % [J/mol/K]
D_H2O  =  2572.63              ;                                     % [K]
E_H2O  =     2.05010  *  4.184 ;                                     % [J/mol/K]
F_H2O  =   1156.72             ;                                     % [K]
G_H2O  =     -3.24989 *  4.184 ;                                     % [J/mol/K]

A = A_H2O ; B = B_H2O ; C = C_H2O ; D = D_H2O ; E = E_H2O ; F = F_H2O ; G = G_H2O ;

% T = 100  ;                                                         % [K]

Sid_H2O = B*log( T ) + C*( ( D/T)*coth( D/T ) - log( sinh( D/T ) ) ) - ...
                           E*( ( F/T)*tanh( F/T ) - log( cosh( F/T ) ) ) + G ;  % [J/mol/K]
                       
return  ;

% Poner Sid_H2O (o cualquier otro nombre) = AL_Sid_H2O (T) con el valor de T correspondiente; en la otra
% ventana