function AL_Sid_fg = AL_Sid_fg( T , x_O2 , x_N2 , x_CO2 , x_H2O )
%
% AL_Sid_fg - Flue gases (O2,N2,CO2,H2O) ideal entropy using Aly&Lee equation.
%
%   Aly, F.A. and Lee, L.L., Self-Consistent Equations for Calculating the Ideal Gas
%   Heat Capacity, Enthalpy and Entropy, Fluid Phase Equilibria, 6 (1981) pp 169-179.
%
%   call  : AL_Sid_fg( T , x_O2 , x_N2 , x_CO2 , x_H2O )
%                where [ T1 ] = [K] and all compositions = [mole f.]
%   return: Sid_fg in [J/mol/K]

AL_Sid_fg = 0 ;                                           % [J/mol/K] init

if( x_O2 > 0 )
    AL_Sid_fg = AL_Sid_fg + x_O2*AL_Sid_O2( T ) ; % [J/mol/K] 
end

if( x_N2 > 0 )
    AL_Sid_fg = AL_Sid_fg + x_N2*AL_Sid_N2( T ) ; % [J/mol/K] 
end

if( x_CO2 > 0 )
    AL_Sid_fg = AL_Sid_fg + x_CO2*AL_Sid_CO2( T ) ; % [J/mol/K] 
end

if( x_H2O > 0 )
    AL_Sid_fg = AL_Sid_fg + x_H2O*AL_Sid_H2O( T ) ; % [J/mol/K] 
end

return ;
