function AL_dSid_fg = AL_dSid_fg( T1 , T2 , x_O2 , x_N2 , x_CO2 , x_H2O )
%
% AL_dSid_fg - Flue gases (O2,N2,CO2,H2O) ideal entropy difference using Aly&Lee equation.
%
%   Aly, F.A. and Lee, L.L., Self-Consistent Equations for Calculating the Ideal Gas
%   Heat Capacity, Enthalpy and Entropy, Fluid Phase Equilibria, 6 (1981) pp 169-179.
%
%   call  : AL_dSid_fg( T1 , T2 , x_O2 , x_N2 , x_CO2 , x_H2O )
%                where [ T1, T2 ] = [K , K] and all compositions = [mole f.]
%   return: dSid_fg in [J/mol/K]

AL_dSid_fg = 0 ;                                           % [J/mol/K] init

if( x_O2 > 0 )
    AL_dSid_fg = AL_dSid_fg + x_O2*AL_dSid_O2( T1 , T2 ) ; % [J/mol/K] 
end

if( x_N2 > 0 )
    AL_dSid_fg = AL_dSid_fg + x_N2*AL_dSid_N2( T1 , T2 ) ; % [J/mol/K] 
end

if( x_CO2 > 0 )
    AL_dSid_fg = AL_dSid_fg + x_CO2*AL_dSid_CO2( T1 , T2 ) ; % [J/mol/K] 
end

if( x_H2O > 0 )
    AL_dSid_fg = AL_dSid_fg + x_H2O*AL_dSid_H2O( T1 , T2 ) ; % [J/mol/K] 
end

return ;
