function Zs = SRK_compress_factors( params )
% Calculates compressibility factors for P , T using the Soave-Redlich-Kwong EoS
%
% Arguments:   params   ( See function SRK_mix_parameters( T , P , ... ) )
%              params   = matrix containing SRK mixture parameters 
%                        [ Amix 0     ...    0             []
%                          Bmix 0     ...    0             []
%                          Dmix 0     ...    0             []
%                          amix 0     ...    0             [bar*L^2/mol^2]
%                          bmix 0     ...    0             [L/mol]
%                          B1   B2    ...    Bn            [] 
%                          A11  A12   ...    A1n           [] cross coefficients
%                          A21  A22   ...    A2n           [] cross coefficients
%                          ...  ...   ...    ...           [] cross coefficients
%                          An1  An2   ...    Ann  ]        [] cross coefficients
% Returns  : [ Z1 Z3 ] [] Greatest and smallest SRK compressibility factors.

% Copyright (c) Fidel Mato & UVa 2016
% Author    : Fidel Mato <fidel@iq.uva.es>
% Maintainer: Fidel Mato <fidel@iq.uva.es>
% Keywords  : Compressibility factor, Cubic EOS , Soave Redlich Kwong

    A    = params( 1 , 1 ) ;                               % []
    B    = params( 2 , 1 ) ;                               % []
    sols = roots( [ 1 , -1 , ( A - B - B^2 ) , -A*B ] ) ;  % []
    Zs   = [ sols(1)  sols(3) ] ;                          % []
 
end
% -------------------------------------------------------------------------------- __END__

