function phii = SRK_parc_fug_coef( i , comp , params , Z )
% Calculates Soave-Redlich-Kwong partial fugacity coefficient for one component.
% Arguments: i      = component (order in the composition vector) for which the
%                     partial fugacity coefficient will be calculated.
%            comp   = molar fraction mixture composition vector.
%            params = (see function SRK_mix_parameters( T , P , ... ) )  
%                     matrix containing SRK mixture parameters 
%                        [ Amix 0     ...    0             []
%                          Bmix 0     ...    0             []
%                          Dmix 0     ...    0             []
%                          amix 0     ...    0             [bar*L^2/mol^2]
%                          bmix 0     ...    0             [L/mol]
%                          B1   B2    ...    Bn            [] 
%                          A11  A12   ...    A1n           [] cross coefficients
%                          A21  A22   ...    A2n           [] cross coefficients
%                          ...  ...   ...    ...           [] cross coefficients
%                          An1  An2   ...    Ann  ]        [] cross coefficients            Z      = mixture compressibility factor       [] 
% Returns  : phii   = ith partial fugacity coefficient     []

% Copyright (c) Fidel Mato & UVa 2016
% Author    : Fidel Mato <fidel@iq.uva.es>
% Maintainer: Fidel Mato <fidel@iq.uva.es>
% Keywords  : Partial fugacity coefficient, Cubic EOS , Soave Redlich Kwong

Amix     = params( 1 , 1 ) ;                               % []
Bmix     = params( 2 , 1 ) ;                               % []
Bi       = params( 6 , i ) ;                               % []
Aijs     = params( 6 + i , : ) ;                           % []

phii     = exp( Bi/Bmix*( Z - 1 ) - log( Z - Bmix )  + ...
           Amix/Bmix*( Bi/Bmix - 2/Amix*sum( comp.*Aijs ) )*log( 1 + Bmix/Z ) ) ; % []

end
% -------------------------------------------------------------------------------- __END__
