function [ Zv Zl ] = PR_1C_compress_factors( T , P , Tc , Pc , w )
% Calculates compressibility factors for P , T using the Peng-Robinson EoS
% Arguments: ( T , P , Tc , Pc , w ) = [ K , bar , K , bar , dimless ]
% Returns  : [ Zv Zl ]               = [ dimless dimless ]

    Tr    = T/Tc ;                                         % [dimless]
    Pr    = P/Pc ;                                         % [dimless]
    alpha = PR_1C_alpha( Tr , w )  ;                       % [dimless]
    A     = 0.45724*alpha*Pr/Tr^2  ;                       % [dimless]
    B     = 0.07780*Pr/Tr          ;                       % [dimless]
    sols  = roots( [ 1 , -( 1 - B ) , ( A -3*B^2 - 2*B ) , -( A*B - B^2 - B^3 ) ] ) ;
    Zv    = sols(1)                ;                       % [dimless]
    Zl    = sols(3)                ;                       % [dimless]
 
end
% -------------------------------------------------------------------------------- __END__

