function [ alpha m ] = SRK_1C_alpha( alpha_function , Tr , w )
% Calculates several alpha functions for the Soave-Redlich-Kwong EoS
% Arguments: ( alpha_function , Tr , w ) = [  string , dimless , dimless ]
%              alpha_function: string defining the alpha function type to use, among
%                             'orig'||'SRK' , 'Ledanois' , 'orig+BM' , 'Ledanois+BM'
% Returns  : [ alpha m] = [ dimless dimless ]

% --------------------------------------------------------------------------- SRK original
if( strcmp( alpha_function , 'orig' ) || strcmp( alpha_function , 'SRK' ) )

    m     = 0.48508 + 1.55171*w - 0.15613*w^2 ;            % [dimless]
    alpha = ( 1 + m*( 1 - sqrt( Tr ) ) )^2    ;            % [dimless]
    return ;

end
 
% ------------------------------------------------------------------------ Ledanois (1998)
if( strcmp( alpha_function , 'Ledanois' ) )

    m = 0.378710697 + 1.487972964*w - 0.16754831*w^2 + 0.017169486*w^3 ; % [dimless]
    alpha = ( 1 + m*( 1 - sqrt( Tr ) ) )^2    ;            % [dimless]
    return ;

end

% -------------------------------------------------------------- Original + Boston-Mathias
% SRK original m + Boston-Mathias (1980)
if( strcmp( alpha_function , 'orig+BM' ) )

    m     = 0.48508 + 1.55171*w - 0.15613*w^2 ;            % [dimless] original SRK
    if( Tr >= 1 )                                          % supercritical
        d     = 1 + m/2                               ;    % [dimless]
        alpha = ( exp( ( 1 - 1/d )*( 1 - Tr^d ) ) )^2 ;    % [dimless]
    else                                                   % subcritical
        alpha = ( 1 + m*( 1 - Tr^0.5 ) )^2            ;    % [dimless] 
    end
    return ;

end

% -------------------------------------------------------------- Ledanois + Boston-Mathias
% Ledanois + Boston-Mathias (1980)
if( strcmp( alpha_function , 'Ledanois+BM' ) )

    m = 0.378710697 + 1.487972964*w - 0.16754831*w^2 + 0.017169486*w^3 ; % [dimless]
    if( Tr >= 1 )                                          % supercritical
        d     = 1 + m/2                               ;    % [dimless]
        alpha = ( exp( ( 1 - 1/d )*( 1 - Tr^d ) ) )^2 ;    % [dimless]
    else                                                   % subcritical
        alpha = ( 1 + m*( 1 - Tr^0.5 ) )^2            ;    % [dimless] 
    end
    return ;

end


end
