function [ Zv Zl ] = SRK_1C_compress_factors( T , P , Tc , Pc , w , alpha_function )
% Calculates compressibility factors for P , T using the Soave-Redlich-Kwong EoS
% Arguments: ( T , P , Tc , Pc , w , alpha_function ) = [ K , bar , K , bar ,
%                                                                 dimless , string ]
%              alpha_function: string defining the alpha function type to use
% Returns  : [ Zv Zl ]               = [ dimless dimless ]

    Tr          = T/Tc ;                                         % [dimless]
    Pr          = P/Pc ;                                         % [dimless]
    [ alpha m ] = SRK_1C_alpha( alpha_function , Tr , w ) ;      % [dimless dimless ]
    A           = 0.42748*alpha*Pr/Tr^2  ;                       % [dimless]
    B           = 0.08664*Pr/Tr          ;                       % [dimless]
    sols        = roots( [ 1 , -1 , ( A - B - B^2 ) , -A*B ] ) ; % [dimless]
    Zv          = sols(1)                ;                       % [dimless]
    Zl          = sols(3)                ;                       % [dimless]
 
end
% -------------------------------------------------------------------------------- __END__

