function [ phase Z1 Z2 ] = SRK_1C_phase_Z( T , P , Tc , Pc , w , alpha_function )
% Calculates phase and compressiblilty factor of a pure compound
% for T , P using the Soave-Redlich-Kwong EoS
% Arguments: ( T , P , Tc , Pc , w , alpha_function ) = [ K , bar , K , bar ,
%                                                                 dimless , string ]
%              alpha_function: string defining the alpha function type to use, among
%                             'orig'||'SRK' , 'Ledanois' , 'orig+BM' , 'Ledanois+BM'
% Returns  : [ phase Z1 Z2 ] , [ string , dimless , dimless ]
%            phase can be: 'V' , 'L' or 'V+L'
%            Z1 , Z2 : equal if 1 phase , or Z1 = Zv , Z2 = Zl if at saturation

[ Zv Zl ] = SRK_1C_compress_factors( T , P , Tc , Pc , w , alpha_function ) ; % [dimless]

if     ( isreal( Zv ) && ~isreal( Zl ) )
    
    phase = 'V' ;
    Z1    = Zv  ;                                          % [dimless]
    Z2    = Zv  ;                                          % [dimless]
    return ;
    
elseif ( ~isreal( Zv ) && isreal( Zl ) )
    
    phase = 'L' ;
    Z1    = Zl  ;                                          % [dimless]
    Z2    = Zl  ;                                          % [dimless]
    return ;
    
elseif ( isreal( Zv ) && isreal( Zl ) )
    
    Psat = SRK_1C_Psat( T , Tc , Pc , w , alpha_function ) ;  % [bar]
    if   ( abs( P - Psat) <= 1e-6 )                        % [bar]
        
        phase = 'L+V' ;
        Z1    = Zv  ;                                      % [dimless]
        Z2    = Zl  ;                                      % [dimless]
        return ;
        
    elseif( P < Psat )
        
        phase = 'V' ;
        Z1    = Zv  ;                                      % [dimless]
        Z2    = Zv  ;                                      % [dimless]
        return ;
        
    elseif( P > Psat )
        
        phase = 'L' ;
        Z1    = Zl  ;                                      % [dimless]
        Z2    = Zl  ;                                      % [dimless]
        return ;
        
    end
    
end

end



