function [ Zv Zl ] = VDW_1C_compress_factors( T , P , Tc , Pc )
% Calculates compressibility factors for P , T using the van der Waals EoS
% Arguments: ( T , P , Tc , Pc ) = [ K , bar , K , bar ]
% Returns  : [ Zv Zl ]           = [ dimless dimless ]

R        = 0.08314459848 ;                                 % [bar*L/mol/K]

a        = 27*R^2*Tc^2/64/Pc ;                             % [bar*L^2/mol^2]
b        = R*Tc/8/Pc         ;                             % [L/mol]

coefz = [ 1 -(b*P/R/T+1) a*P/R^2/T^2 -a*b*P^2/R^3/T^3 ];   % [dimless]
solsZ = roots(coefz) ;
Zv    = solsZ(1);                                          % [dimless]
Zl    = solsZ(3);                                          % [dimless]

end
