function dS12id = dSid_Polynomial_3( T1 , P1 , T2 , P2 , params )
% Calculates the ideal entropy change between T1 , P1 and T2 , P2 using
% a 3dr order polynomial correlation for the ideal heat capacity:
%     Cp = A + B*T + C*T^2 + D*T^3 , Cp = [J/mol/K] , T = [K]
% Arguments: ( T1 , P1 , ...  = [ K , bar , ... ]
%              T2 , P2 , ...  = [ K , bar , ... ]
%                  params )   = [ A B C D ] to yield Cp in J/mol/K 
% Returns  : dS12id           = [ J/mol/K ]

R        = 8.314459848 ;                                   % [J/mol/K]

A        = params( 1 ) ;
B        = params( 2 ) ;
C        = params( 3 ) ;
D        = params( 4 ) ;

dS12id   =  A*log( T2/T1 ) + B*( T2 - T1 ) + ...
            C/2*( T2^2 - T1^2 ) + D/3*( T2^3 - T1^3 ) - R*log( P2/P1 ) ;  % [J/mol/K]

end
